@@ -6,7 +6,7 @@ import signal
 import requests
 import yaml
 
-from kikyopp.utils import configure_logger
+from kikyopp.utils.logging import configure_logger
 from kikyopp.worker import BaseWorker
 
 log = logging.getLogger(__name__)
